*************
CLI Reference
*************

Please find an examples of CLI Tool usage :ref:`here <usage_examples>`.

See full list of CLI options below.

Primary command:

.. click:: spoonbill.cli:cli
   :prog: spoonbill
   :nested: full
